@@ -108,12 +108,6 @@ typedef struct {
 	/* The popup window and scale. */
 	GtkWidget         *popup;
 	GtkWidget         *scale;
-
-	GdkPixbuf         *zero_pixbuf;
-	GdkPixbuf         *min_pixbuf;
-	GdkPixbuf         *medium_pixbuf;
-	GdkPixbuf         *max_pixbuf;
-	GdkPixbuf         *mute_pixbuf;
 } MixerData;
 
 static void mixer_update_slider (MixerData *data);
@@ -122,10 +116,13 @@ static void mixer_popup_show    (MixerData *data);
 static void mixer_popup_hide    (MixerData *data, gboolean revert);
 
 static void mixer_start_gmix_cb (BonoboUIComponent *uic,
-				 MixerData         *data,
+				 gpointer           data,
 				 const gchar       *verbname);
 
-static gint       mixerfd = -1;
+
+static gint mixerfd = -1;
+static GdkPixbuf *zero_pixbuf = NULL, *min_pixbuf, *medium_pixbuf, *max_pixbuf, *mute_pixbuf;
+
 
 #ifdef OSS_API
 static int mixerchannel;
@@ -344,16 +341,16 @@ mixer_update_image (MixerData *data)
 	vol = data->vol;
 	
 	if (vol <= 0) {
-		pixbuf = data->zero_pixbuf;
+		pixbuf = zero_pixbuf;
 	}
 	else if (vol <= VOLUME_MAX / 3) {
-		pixbuf = data->min_pixbuf;
+		pixbuf = min_pixbuf;
 	}
 	else if (vol <= 2 * VOLUME_MAX / 3) {
-		pixbuf = data->medium_pixbuf;
+		pixbuf = medium_pixbuf;
 	}
 	else {
-		pixbuf = data->max_pixbuf;
+		pixbuf = max_pixbuf;
 	}
 
 	if (!data->mute) {
@@ -361,12 +358,12 @@ mixer_update_image (MixerData *data)
 	} else {
 		GdkPixbuf *copy = gdk_pixbuf_copy (pixbuf);
 
-		gdk_pixbuf_composite (data->mute_pixbuf,
+		gdk_pixbuf_composite (mute_pixbuf,
 				      copy,
 				      0,
 				      0,
-				      gdk_pixbuf_get_width (data->mute_pixbuf),
-				      gdk_pixbuf_get_height (data->mute_pixbuf),
+				      gdk_pixbuf_get_width (mute_pixbuf),
+				      gdk_pixbuf_get_height (mute_pixbuf),
 				      0,
 				      0,
 				      1.0,
@@ -407,6 +404,7 @@ scale_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *data
 static gboolean
 scale_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerData *data)
 {
+
 	if (data->popup != NULL) {
 		mixer_popup_hide (data, FALSE);
 		return TRUE;
@@ -416,23 +414,42 @@ scale_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerDa
 }
 
 static gboolean
-button_press_event_cb (GtkWidget *widget, GdkEventButton *event, MixerData *data)
+applet_button_release_event_cb (GtkWidget *widget, GdkEventButton *event, MixerData *data)
 {
-	if (data->popup != NULL) {
-		mixer_popup_hide (data, FALSE);
-		return TRUE;
-	} else {
-		if (event->button == 1) {
-			if (event->type == GDK_2BUTTON_PRESS) {
-				mixer_start_gmix_cb (NULL, data, NULL);
-			} else {
-				mixer_popup_show (data);
-			}
+	if (event->button == 1) {
+		if (data->popup == NULL) {
+			mixer_popup_show (data);
+			return TRUE;
 		}
 	}
 
-	if (event->button == 2) {
-		g_print ("Button2: Why won't the panel get this event?\n");
+	return FALSE;
+}
+
+static gboolean
+applet_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *data)
+{
+	switch (event->keyval) {
+	case GDK_Escape:
+		/* Revert. */
+		mixer_popup_hide (data, TRUE);
+		return TRUE;
+
+	case GDK_KP_Enter:
+	case GDK_ISO_Enter:
+	case GDK_3270_Enter:
+	case GDK_Return:
+	case GDK_space:
+	case GDK_KP_Space:
+		/* Apply. */
+		if (data->popup != NULL)
+			mixer_popup_hide (data, FALSE);
+		else
+			mixer_popup_show (data);
+		return TRUE;
+
+	default:
+		break;
 	}
 
 	return FALSE;
@@ -617,27 +634,6 @@ destroy_mixer_cb (GtkWidget *widget, MixerData *data)
 		data->timeout = 0;
 	}
 
-	if (data->zero_pixbuf) {
-		g_object_unref (data->zero_pixbuf);
-		data->zero_pixbuf = NULL;
-	}
-	if (data->min_pixbuf) {
-		g_object_unref (data->min_pixbuf);
-		data->min_pixbuf = NULL;
-	}
-	if (data->medium_pixbuf) {
-		g_object_unref (data->medium_pixbuf);
-		data->medium_pixbuf = NULL;
-	}
-	if (data->max_pixbuf) {
-		g_object_unref (data->max_pixbuf);
-		data->max_pixbuf = NULL;
-	}
-	if (data->mute_pixbuf) {
-		g_object_unref (data->mute_pixbuf);
-		data->mute_pixbuf = NULL;
-	}
-	
 	g_free (data);
 }
 
@@ -693,7 +689,7 @@ applet_change_size_cb (GtkWidget *w, gint size, MixerData *data)
 
 static void
 mixer_start_gmix_cb (BonoboUIComponent *uic,
-		     MixerData         *data,
+		     gpointer           data,
 		     const gchar       *verbname)
 {
 	gnome_execute_shell (NULL, "gnome-volume-control");
@@ -701,7 +697,7 @@ mixer_start_gmix_cb (BonoboUIComponent *uic,
 
 static void
 mixer_about_cb (BonoboUIComponent *uic,
-		MixerData         *data,
+		gpointer           data,
 		const gchar       *verbname)
 {
         static GtkWidget   *about     = NULL;
@@ -732,7 +728,7 @@ mixer_about_cb (BonoboUIComponent *uic,
 
 static void
 mixer_help_cb (BonoboUIComponent *uic,
-	       MixerData         *data,
+	       gpointer           data,
 	       const gchar       *verbname)
 {
 #if 0
@@ -748,7 +744,7 @@ mixer_help_cb (BonoboUIComponent *uic,
 /* Dummy callback to get rid of a warning, for now. */
 static void
 mixer_mute_cb (BonoboUIComponent *uic,
-	       MixerData         *data,
+	       gpointer           data,
 	       const gchar       *verbname)
 {
 }
@@ -786,27 +782,17 @@ mixer_ui_component_event (BonoboUIComponent            *comp,
 	}
 }
 
-static const BonoboUIVerb mixer_applet_menu_verbs [] = {
-	BONOBO_UI_UNSAFE_VERB ("RunMixer", mixer_start_gmix_cb),
-	BONOBO_UI_UNSAFE_VERB ("Mute",     mixer_mute_cb),
-	BONOBO_UI_UNSAFE_VERB ("Help",     mixer_help_cb),
-	BONOBO_UI_UNSAFE_VERB ("About",    mixer_about_cb),
-
+const BonoboUIVerb mixer_applet_menu_verbs [] = {
+	BONOBO_UI_VERB ("RunMixer", mixer_start_gmix_cb),
+	BONOBO_UI_VERB ("Mute",     mixer_mute_cb),
+	BONOBO_UI_VERB ("Help",     mixer_help_cb),
+	BONOBO_UI_VERB ("About",    mixer_about_cb),
+	
         BONOBO_UI_VERB_END
 };
 
-static const char mixer_applet_menu_xml [] =
-"<popup name=\"button3\">\n"
-"   <menuitem name=\"RunMixer\" verb=\"RunMixer\" _label=\"Run Audio Mixer...\"\n/>"
-"   <menuitem name=\"Mute\" verb=\"Mute\" type=\"toggle\" _label=\"Mute\"\n/>"
-"   <menuitem name=\"Help\" verb=\"Help\" _label=\"Help\"\n"
-"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-"   <menuitem name=\"About\" verb=\"About\" _label=\"About...\"\n"
-"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-"</popup>\n";
-
 static void
-mixer_applet_fill (PanelApplet *applet)
+mixer_applet_create (PanelApplet *applet)
 {
 	MixerData         *data;
 	BonoboUIComponent *component;
@@ -820,11 +806,13 @@ mixer_applet_fill (PanelApplet *applet)
 
 	data = g_new0 (MixerData, 1);
 
-	data->zero_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_zero_xpm);
-	data->min_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_min_xpm);
-	data->medium_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_medium_xpm);
-	data->max_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_max_xpm);
-	data->mute_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_mute_xpm);
+	if (zero_pixbuf == NULL) {
+		zero_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_zero_xpm);
+		min_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_min_xpm);
+		medium_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_medium_xpm);
+		max_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_max_xpm);
+		mute_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_mute_xpm);
+	}
 	
 	data->frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (data->frame), GTK_SHADOW_NONE);
@@ -836,19 +824,24 @@ mixer_applet_fill (PanelApplet *applet)
 	data->applet = GTK_WIDGET (applet);
 	
 	g_signal_connect (data->applet,
-			  "button-press-event",
-			  (GCallback) button_press_event_cb,
+			  "button-release-event",
+			  (GCallback) applet_button_release_event_cb,
+			  data);
+	
+	g_signal_connect (data->applet,
+			  "key-press-event",
+			  (GCallback) applet_key_press_event_cb,
 			  data);
 	
         data->adj = GTK_ADJUSTMENT (
 		gtk_adjustment_new (-50,
 				    -VOLUME_MAX,
 				    0.0, 
-				    VOLUME_MAX/100,
+				    VOLUME_MAX/20,
 				    VOLUME_MAX/10,
 				    0.0));
 
-	g_signal_connect (GTK_OBJECT (data->adj),
+	g_signal_connect (data->adj,
 			  "value-changed",
 			  (GCallback) mixer_value_changed_cb,
 			  data);
@@ -865,45 +858,46 @@ mixer_applet_fill (PanelApplet *applet)
 
 	data->mute = FALSE;
 
-	g_signal_connect (G_OBJECT (applet),
+	g_signal_connect (applet,
 			  "destroy",
 			  (GCallback) destroy_mixer_cb,
 			  data);
 
-	g_signal_connect (G_OBJECT (applet),
+	g_signal_connect (applet,
 			  "change_orient",
 			  G_CALLBACK (applet_change_orient_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (applet),
+	g_signal_connect (applet,
 			  "change_size",
 			  G_CALLBACK (applet_change_size_cb),
 			  data);
 
-	g_signal_connect (G_OBJECT (applet),
+	g_signal_connect (applet,
 			  "change_background",
 			  G_CALLBACK (applet_change_background_cb),
 			  data);
-	
-	component = panel_applet_get_popup_component (PANEL_APPLET (applet));
 
+	panel_applet_setup_menu_from_file (applet, 
+					   NULL, /* opt_datadir */
+					   "GNOME_MixerApplet.xml",
+					   NULL,
+					   mixer_applet_menu_verbs,
+					   data);
+
+	component = panel_applet_get_popup_component (applet);
 	g_signal_connect (component,
 			  "ui-event",
 			  (GCallback) mixer_ui_component_event,
 			  data);
 
-	panel_applet_setup_menu (PANEL_APPLET (applet),
-				 mixer_applet_menu_xml,
-				 mixer_applet_menu_verbs,
-				 data);
-
 	applet_change_orient_cb (GTK_WIDGET (applet),
-				 panel_applet_get_orient (PANEL_APPLET (applet)),
+				 panel_applet_get_orient (applet),
 				 data);
 	applet_change_size_cb (GTK_WIDGET (applet),
-			       panel_applet_get_size (PANEL_APPLET (applet)),
+			       panel_applet_get_size (applet),
 			       data);
-	
+
 	mixer_update_slider (data);
 	mixer_update_image (data);
 
@@ -915,13 +909,13 @@ mixer_applet_factory (PanelApplet *applet,
 		      const gchar *iid,
 		      gpointer     data)
 {
-	if (!strcmp (iid, "OAFIID:GNOME_MixerApplet"))
-		mixer_applet_fill (applet);
-	
+	mixer_applet_create (applet);
+
 	return TRUE;
 }
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_MixerApplet_Factory",
+			     PANEL_TYPE_APPLET,
 			     "Volume control applet",
 			     "0",
 			     mixer_applet_factory,
